@@ -1,21 +1,21 @@
 # Licensed under the Apache License: http://www.apache.org/licenses/LICENSE-2.0
 # For details: https://github.com/gaogaotiantian/objprint/blob/master/NOTICE.txt
 
-__version__ = "0.1.0"
+__version__ = "0.1.2"
 
 
 from .objprint import ObjPrint
 from .decorator import add_objprint
 
 _objprint = ObjPrint()
-objprint = _objprint.objprint
+op = objprint = _objprint.objprint
 objstr = _objprint.objstr
 config = _objprint.config
 install = _objprint.install
 
 
 __all__ = [
-    "objprint",
+    "op",
     "objstr",
     "config",
     "add_objprint",
