@@ -2,13 +2,13 @@
 # For details: https://github.com/gaogaotiantian/objprint/blob/master/NOTICE.txt
 
 
-def add_objprint(orig_class=None, include=[], exclude=[]):
-
-    def __str__(self):
-        return _objprint._get_custom_object_str(self, indent_level=0, include=include, exclude=exclude)
+def add_objprint(orig_class=None, **kwargs):
 
     from . import _objprint
 
+    def __str__(self):
+        return _objprint._get_custom_object_str(self, indent_level=0, cfg=_objprint._configs.overwrite(**kwargs))
+
     if orig_class is None:
         def wrapper(cls):
             cls.__str__ = __str__
